@@ -26,7 +26,7 @@ def _make_credentials():
     return mock.Mock(spec=google.auth.credentials.Credentials)
 
 
-def _make_response(status=http_client.OK, content=b'', headers={}):
+def _make_response(status=http_client.OK, content=b"", headers={}):
     response = requests.Response()
     response.status_code = status
     response._content = content
@@ -37,11 +37,10 @@ def _make_response(status=http_client.OK, content=b'', headers={}):
 
 def _make_json_response(data, status=http_client.OK, headers=None):
     headers = headers or {}
-    headers['Content-Type'] = 'application/json'
+    headers["Content-Type"] = "application/json"
     return _make_response(
-        status=status,
-        content=json.dumps(data).encode('utf-8'),
-        headers=headers)
+        status=status, content=json.dumps(data).encode("utf-8"), headers=headers
+    )
 
 
 def _make_requests_session(responses):
@@ -51,7 +50,6 @@ def _make_requests_session(responses):
 
 
 class TestClient(unittest.TestCase):
-
     @staticmethod
     def _get_target_class():
         from google.cloud.storage.client import Client
@@ -64,7 +62,7 @@ class TestClient(unittest.TestCase):
     def test_ctor_connection_type(self):
         from google.cloud.storage._http import Connection
 
-        PROJECT = 'PROJECT'
+        PROJECT = "PROJECT"
         CREDENTIALS = _make_credentials()
 
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
@@ -78,12 +76,12 @@ class TestClient(unittest.TestCase):
     def test_ctor_wo_project(self):
         from google.cloud.storage._http import Connection
 
-        PROJECT = 'PROJECT'
+        PROJECT = "PROJECT"
         CREDENTIALS = _make_credentials()
 
         ddp_patch = mock.patch(
-            'google.cloud.client._determine_default_project',
-            return_value=PROJECT)
+            "google.cloud.client._determine_default_project", return_value=PROJECT
+        )
 
         with ddp_patch:
             client = self._make_one(credentials=CREDENTIALS)
@@ -116,13 +114,12 @@ class TestClient(unittest.TestCase):
 
         self.assertIsNone(client.project)
         self.assertIsInstance(client._connection, Connection)
-        self.assertIsInstance(
-            client._connection.credentials, AnonymousCredentials)
+        self.assertIsInstance(client._connection.credentials, AnonymousCredentials)
 
     def test__push_batch_and__pop_batch(self):
         from google.cloud.storage.batch import Batch
 
-        PROJECT = 'PROJECT'
+        PROJECT = "PROJECT"
         CREDENTIALS = _make_credentials()
 
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
@@ -141,7 +138,7 @@ class TestClient(unittest.TestCase):
         self.assertEqual(list(client._batch_stack), [])
 
     def test__connection_setter(self):
-        PROJECT = 'PROJECT'
+        PROJECT = "PROJECT"
         CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
         client._base_connection = None  # Unset the value from the constructor
@@ -149,13 +146,13 @@ class TestClient(unittest.TestCase):
         self.assertIs(client._base_connection, connection)
 
     def test__connection_setter_when_set(self):
-        PROJECT = 'PROJECT'
+        PROJECT = "PROJECT"
         CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
-        self.assertRaises(ValueError, setattr, client, '_connection', None)
+        self.assertRaises(ValueError, setattr, client, "_connection", None)
 
     def test__connection_getter_no_batch(self):
-        PROJECT = 'PROJECT'
+        PROJECT = "PROJECT"
         CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
         self.assertIs(client._connection, client._base_connection)
@@ -164,7 +161,7 @@ class TestClient(unittest.TestCase):
     def test__connection_getter_with_batch(self):
         from google.cloud.storage.batch import Batch
 
-        PROJECT = 'PROJECT'
+        PROJECT = "PROJECT"
         CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
         batch = Batch(client)
@@ -174,65 +171,62 @@ class TestClient(unittest.TestCase):
         self.assertIs(client.current_batch, batch)
 
     def test_get_service_account_email_wo_project(self):
-        PROJECT = 'PROJECT'
+        PROJECT = "PROJECT"
         CREDENTIALS = _make_credentials()
-        EMAIL = 'storage-user-123@example.com'
-        RESOURCE = {
-            'kind': 'storage#serviceAccount',
-            'email_address': EMAIL,
-        }
+        EMAIL = "storage-user-123@example.com"
+        RESOURCE = {"kind": "storage#serviceAccount", "email_address": EMAIL}
 
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
-        http = _make_requests_session([
-            _make_json_response(RESOURCE)])
+        http = _make_requests_session([_make_json_response(RESOURCE)])
         client._http_internal = http
 
         service_account_email = client.get_service_account_email()
 
         self.assertEqual(service_account_email, EMAIL)
-        URI = '/'.join([
-            client._connection.API_BASE_URL,
-            'storage',
-            client._connection.API_VERSION,
-            'projects/%s/serviceAccount' % (PROJECT,)
-        ])
+        URI = "/".join(
+            [
+                client._connection.API_BASE_URL,
+                "storage",
+                client._connection.API_VERSION,
+                "projects/%s/serviceAccount" % (PROJECT,),
+            ]
+        )
         http.request.assert_called_once_with(
-            method='GET', url=URI, data=None, headers=mock.ANY)
+            method="GET", url=URI, data=None, headers=mock.ANY
+        )
 
     def test_get_service_account_email_w_project(self):
-        PROJECT = 'PROJECT'
-        OTHER_PROJECT = 'OTHER_PROJECT'
+        PROJECT = "PROJECT"
+        OTHER_PROJECT = "OTHER_PROJECT"
         CREDENTIALS = _make_credentials()
-        EMAIL = 'storage-user-123@example.com'
-        RESOURCE = {
-            'kind': 'storage#serviceAccount',
-            'email_address': EMAIL,
-        }
+        EMAIL = "storage-user-123@example.com"
+        RESOURCE = {"kind": "storage#serviceAccount", "email_address": EMAIL}
 
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
-        http = _make_requests_session([
-            _make_json_response(RESOURCE)])
+        http = _make_requests_session([_make_json_response(RESOURCE)])
         client._http_internal = http
 
-        service_account_email = client.get_service_account_email(
-            project=OTHER_PROJECT)
+        service_account_email = client.get_service_account_email(project=OTHER_PROJECT)
 
         self.assertEqual(service_account_email, EMAIL)
-        URI = '/'.join([
-            client._connection.API_BASE_URL,
-            'storage',
-            client._connection.API_VERSION,
-            'projects/%s/serviceAccount' % (OTHER_PROJECT,)
-        ])
+        URI = "/".join(
+            [
+                client._connection.API_BASE_URL,
+                "storage",
+                client._connection.API_VERSION,
+                "projects/%s/serviceAccount" % (OTHER_PROJECT,),
+            ]
+        )
         http.request.assert_called_once_with(
-            method='GET', url=URI, data=None, headers=mock.ANY)
+            method="GET", url=URI, data=None, headers=mock.ANY
+        )
 
     def test_bucket(self):
         from google.cloud.storage.bucket import Bucket
 
-        PROJECT = 'PROJECT'
+        PROJECT = "PROJECT"
         CREDENTIALS = _make_credentials()
-        BUCKET_NAME = 'BUCKET_NAME'
+        BUCKET_NAME = "BUCKET_NAME"
 
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
         bucket = client.bucket(BUCKET_NAME)
@@ -244,10 +238,10 @@ class TestClient(unittest.TestCase):
     def test_bucket_w_user_project(self):
         from google.cloud.storage.bucket import Bucket
 
-        PROJECT = 'PROJECT'
-        USER_PROJECT = 'USER_PROJECT'
+        PROJECT = "PROJECT"
+        USER_PROJECT = "USER_PROJECT"
         CREDENTIALS = _make_credentials()
-        BUCKET_NAME = 'BUCKET_NAME'
+        BUCKET_NAME = "BUCKET_NAME"
 
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
         bucket = client.bucket(BUCKET_NAME, user_project=USER_PROJECT)
@@ -259,7 +253,7 @@ class TestClient(unittest.TestCase):
     def test_batch(self):
         from google.cloud.storage.batch import Batch
 
-        PROJECT = 'PROJECT'
+        PROJECT = "PROJECT"
         CREDENTIALS = _make_credentials()
 
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
@@ -270,45 +264,51 @@ class TestClient(unittest.TestCase):
     def test_get_bucket_miss(self):
         from google.cloud.exceptions import NotFound
 
-        PROJECT = 'PROJECT'
+        PROJECT = "PROJECT"
         CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
 
-        NONESUCH = 'nonesuch'
-        URI = '/'.join([
-            client._connection.API_BASE_URL,
-            'storage',
-            client._connection.API_VERSION,
-            'b',
-            'nonesuch?projection=noAcl',
-        ])
-        http = _make_requests_session([
-            _make_json_response({}, status=http_client.NOT_FOUND)])
+        NONESUCH = "nonesuch"
+        URI = "/".join(
+            [
+                client._connection.API_BASE_URL,
+                "storage",
+                client._connection.API_VERSION,
+                "b",
+                "nonesuch?projection=noAcl",
+            ]
+        )
+        http = _make_requests_session(
+            [_make_json_response({}, status=http_client.NOT_FOUND)]
+        )
         client._http_internal = http
 
         with self.assertRaises(NotFound):
             client.get_bucket(NONESUCH)
 
         http.request.assert_called_once_with(
-            method='GET', url=URI, data=mock.ANY, headers=mock.ANY)
+            method="GET", url=URI, data=mock.ANY, headers=mock.ANY
+        )
 
     def test_get_bucket_hit(self):
         from google.cloud.storage.bucket import Bucket
 
-        PROJECT = 'PROJECT'
+        PROJECT = "PROJECT"
         CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
 
-        BUCKET_NAME = 'bucket-name'
-        URI = '/'.join([
-            client._connection.API_BASE_URL,
-            'storage',
-            client._connection.API_VERSION,
-            'b',
-            '%s?projection=noAcl' % (BUCKET_NAME,),
-        ])
+        BUCKET_NAME = "bucket-name"
+        URI = "/".join(
+            [
+                client._connection.API_BASE_URL,
+                "storage",
+                client._connection.API_VERSION,
+                "b",
+                "%s?projection=noAcl" % (BUCKET_NAME,),
+            ]
+        )
 
-        data = {'name': BUCKET_NAME}
+        data = {"name": BUCKET_NAME}
         http = _make_requests_session([_make_json_response(data)])
         client._http_internal = http
 
@@ -317,47 +317,54 @@ class TestClient(unittest.TestCase):
         self.assertIsInstance(bucket, Bucket)
         self.assertEqual(bucket.name, BUCKET_NAME)
         http.request.assert_called_once_with(
-            method='GET', url=URI, data=mock.ANY, headers=mock.ANY)
+            method="GET", url=URI, data=mock.ANY, headers=mock.ANY
+        )
 
     def test_lookup_bucket_miss(self):
-        PROJECT = 'PROJECT'
+        PROJECT = "PROJECT"
         CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
 
-        NONESUCH = 'nonesuch'
-        URI = '/'.join([
-            client._connection.API_BASE_URL,
-            'storage',
-            client._connection.API_VERSION,
-            'b',
-            'nonesuch?projection=noAcl',
-        ])
-        http = _make_requests_session([
-            _make_json_response({}, status=http_client.NOT_FOUND)])
+        NONESUCH = "nonesuch"
+        URI = "/".join(
+            [
+                client._connection.API_BASE_URL,
+                "storage",
+                client._connection.API_VERSION,
+                "b",
+                "nonesuch?projection=noAcl",
+            ]
+        )
+        http = _make_requests_session(
+            [_make_json_response({}, status=http_client.NOT_FOUND)]
+        )
         client._http_internal = http
 
         bucket = client.lookup_bucket(NONESUCH)
 
         self.assertIsNone(bucket)
         http.request.assert_called_once_with(
-            method='GET', url=URI, data=mock.ANY, headers=mock.ANY)
+            method="GET", url=URI, data=mock.ANY, headers=mock.ANY
+        )
 
     def test_lookup_bucket_hit(self):
         from google.cloud.storage.bucket import Bucket
 
-        PROJECT = 'PROJECT'
+        PROJECT = "PROJECT"
         CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
 
-        BUCKET_NAME = 'bucket-name'
-        URI = '/'.join([
-            client._connection.API_BASE_URL,
-            'storage',
-            client._connection.API_VERSION,
-            'b',
-            '%s?projection=noAcl' % (BUCKET_NAME,),
-        ])
-        data = {'name': BUCKET_NAME}
+        BUCKET_NAME = "bucket-name"
+        URI = "/".join(
+            [
+                client._connection.API_BASE_URL,
+                "storage",
+                client._connection.API_VERSION,
+                "b",
+                "%s?projection=noAcl" % (BUCKET_NAME,),
+            ]
+        )
+        data = {"name": BUCKET_NAME}
         http = _make_requests_session([_make_json_response(data)])
         client._http_internal = http
 
@@ -366,52 +373,59 @@ class TestClient(unittest.TestCase):
         self.assertIsInstance(bucket, Bucket)
         self.assertEqual(bucket.name, BUCKET_NAME)
         http.request.assert_called_once_with(
-            method='GET', url=URI, data=mock.ANY, headers=mock.ANY)
+            method="GET", url=URI, data=mock.ANY, headers=mock.ANY
+        )
 
     def test_create_bucket_conflict(self):
         from google.cloud.exceptions import Conflict
 
-        PROJECT = 'PROJECT'
-        OTHER_PROJECT = 'OTHER_PROJECT'
+        PROJECT = "PROJECT"
+        OTHER_PROJECT = "OTHER_PROJECT"
         CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
 
-        BUCKET_NAME = 'bucket-name'
-        URI = '/'.join([
-            client._connection.API_BASE_URL,
-            'storage',
-            client._connection.API_VERSION,
-            'b?project=%s' % (OTHER_PROJECT,),
-        ])
-        data = {'error': {'message': 'Conflict'}}
-        sent = {'name': BUCKET_NAME}
-        http = _make_requests_session([
-            _make_json_response(data, status=http_client.CONFLICT)])
+        BUCKET_NAME = "bucket-name"
+        URI = "/".join(
+            [
+                client._connection.API_BASE_URL,
+                "storage",
+                client._connection.API_VERSION,
+                "b?project=%s" % (OTHER_PROJECT,),
+            ]
+        )
+        data = {"error": {"message": "Conflict"}}
+        sent = {"name": BUCKET_NAME}
+        http = _make_requests_session(
+            [_make_json_response(data, status=http_client.CONFLICT)]
+        )
         client._http_internal = http
 
         with self.assertRaises(Conflict):
             client.create_bucket(BUCKET_NAME, project=OTHER_PROJECT)
 
         http.request.assert_called_once_with(
-            method='POST', url=URI, data=mock.ANY, headers=mock.ANY)
-        json_sent = http.request.call_args_list[0][1]['data']
+            method="POST", url=URI, data=mock.ANY, headers=mock.ANY
+        )
+        json_sent = http.request.call_args_list[0][1]["data"]
         self.assertEqual(sent, json.loads(json_sent))
 
     def test_create_bucket_success(self):
         from google.cloud.storage.bucket import Bucket
 
-        PROJECT = 'PROJECT'
+        PROJECT = "PROJECT"
         CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
 
-        BUCKET_NAME = 'bucket-name'
-        URI = '/'.join([
-            client._connection.API_BASE_URL,
-            'storage',
-            client._connection.API_VERSION,
-            'b?project=%s' % (PROJECT,),
-        ])
-        sent = {'name': BUCKET_NAME, 'billing': {'requesterPays': True}}
+        BUCKET_NAME = "bucket-name"
+        URI = "/".join(
+            [
+                client._connection.API_BASE_URL,
+                "storage",
+                client._connection.API_VERSION,
+                "b?project=%s" % (PROJECT,),
+            ]
+        )
+        sent = {"name": BUCKET_NAME, "billing": {"requesterPays": True}}
         data = sent
         http = _make_requests_session([_make_json_response(data)])
         client._http_internal = http
@@ -422,8 +436,9 @@ class TestClient(unittest.TestCase):
         self.assertEqual(bucket.name, BUCKET_NAME)
         self.assertTrue(bucket.requester_pays)
         http.request.assert_called_once_with(
-            method='POST', url=URI, data=mock.ANY, headers=mock.ANY)
-        json_sent = http.request.call_args_list[0][1]['data']
+            method="POST", url=URI, data=mock.ANY, headers=mock.ANY
+        )
+        json_sent = http.request.call_args_list[0][1]["data"]
         self.assertEqual(sent, json.loads(json_sent))
 
     def test_list_buckets_wo_project(self):
@@ -437,7 +452,7 @@ class TestClient(unittest.TestCase):
         from six.moves.urllib.parse import parse_qs
         from six.moves.urllib.parse import urlparse
 
-        PROJECT = 'PROJECT'
+        PROJECT = "PROJECT"
         CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
 
@@ -449,21 +464,21 @@ class TestClient(unittest.TestCase):
         self.assertEqual(len(buckets), 0)
 
         http.request.assert_called_once_with(
-            method='GET', url=mock.ANY, data=mock.ANY, headers=mock.ANY)
+            method="GET", url=mock.ANY, data=mock.ANY, headers=mock.ANY
+        )
 
-        requested_url = http.request.mock_calls[0][2]['url']
-        expected_base_url = '/'.join([
-            client._connection.API_BASE_URL,
-            'storage',
-            client._connection.API_VERSION,
-            'b',
-        ])
+        requested_url = http.request.mock_calls[0][2]["url"]
+        expected_base_url = "/".join(
+            [
+                client._connection.API_BASE_URL,
+                "storage",
+                client._connection.API_VERSION,
+                "b",
+            ]
+        )
         self.assertTrue(requested_url.startswith(expected_base_url))
 
-        expected_query = {
-            'project': [PROJECT],
-            'projection': ['noAcl'],
-        }
+        expected_query = {"project": [PROJECT], "projection": ["noAcl"]}
         uri_parts = urlparse(requested_url)
         self.assertEqual(parse_qs(uri_parts.query), expected_query)
 
@@ -471,8 +486,8 @@ class TestClient(unittest.TestCase):
         from six.moves.urllib.parse import parse_qs
         from six.moves.urllib.parse import urlparse
 
-        PROJECT = 'PROJECT'
-        OTHER_PROJECT = 'OTHER_PROJECT'
+        PROJECT = "PROJECT"
+        OTHER_PROJECT = "OTHER_PROJECT"
         CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
 
@@ -484,32 +499,32 @@ class TestClient(unittest.TestCase):
         self.assertEqual(len(buckets), 0)
 
         http.request.assert_called_once_with(
-            method='GET', url=mock.ANY, data=mock.ANY, headers=mock.ANY)
+            method="GET", url=mock.ANY, data=mock.ANY, headers=mock.ANY
+        )
 
-        requested_url = http.request.mock_calls[0][2]['url']
-        expected_base_url = '/'.join([
-            client._connection.API_BASE_URL,
-            'storage',
-            client._connection.API_VERSION,
-            'b',
-        ])
+        requested_url = http.request.mock_calls[0][2]["url"]
+        expected_base_url = "/".join(
+            [
+                client._connection.API_BASE_URL,
+                "storage",
+                client._connection.API_VERSION,
+                "b",
+            ]
+        )
         self.assertTrue(requested_url.startswith(expected_base_url))
 
-        expected_query = {
-            'project': [OTHER_PROJECT],
-            'projection': ['noAcl'],
-        }
+        expected_query = {"project": [OTHER_PROJECT], "projection": ["noAcl"]}
         uri_parts = urlparse(requested_url)
         self.assertEqual(parse_qs(uri_parts.query), expected_query)
 
     def test_list_buckets_non_empty(self):
-        PROJECT = 'PROJECT'
+        PROJECT = "PROJECT"
         CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
 
-        BUCKET_NAME = 'bucket-name'
+        BUCKET_NAME = "bucket-name"
 
-        data = {'items': [{'name': BUCKET_NAME}]}
+        data = {"items": [{"name": BUCKET_NAME}]}
         http = _make_requests_session([_make_json_response(data)])
         client._http_internal = http
 
@@ -519,23 +534,24 @@ class TestClient(unittest.TestCase):
         self.assertEqual(buckets[0].name, BUCKET_NAME)
 
         http.request.assert_called_once_with(
-            method='GET', url=mock.ANY, data=mock.ANY, headers=mock.ANY)
+            method="GET", url=mock.ANY, data=mock.ANY, headers=mock.ANY
+        )
 
     def test_list_buckets_all_arguments(self):
         from six.moves.urllib.parse import parse_qs
         from six.moves.urllib.parse import urlparse
 
-        PROJECT = 'foo-bar'
+        PROJECT = "foo-bar"
         CREDENTIALS = _make_credentials()
         client = self._make_one(project=PROJECT, credentials=CREDENTIALS)
 
         MAX_RESULTS = 10
-        PAGE_TOKEN = 'ABCD'
-        PREFIX = 'subfolder'
-        PROJECTION = 'full'
-        FIELDS = 'items/id,nextPageToken'
+        PAGE_TOKEN = "ABCD"
+        PREFIX = "subfolder"
+        PROJECTION = "full"
+        FIELDS = "items/id,nextPageToken"
 
-        data = {'items': []}
+        data = {"items": []}
         http = _make_requests_session([_make_json_response(data)])
         client._http_internal = http
         iterator = client.list_buckets(
@@ -548,24 +564,27 @@ class TestClient(unittest.TestCase):
         buckets = list(iterator)
         self.assertEqual(buckets, [])
         http.request.assert_called_once_with(
-            method='GET', url=mock.ANY, data=mock.ANY, headers=mock.ANY)
+            method="GET", url=mock.ANY, data=mock.ANY, headers=mock.ANY
+        )
 
-        requested_url = http.request.mock_calls[0][2]['url']
-        expected_base_url = '/'.join([
-            client._connection.API_BASE_URL,
-            'storage',
-            client._connection.API_VERSION,
-            'b',
-        ])
+        requested_url = http.request.mock_calls[0][2]["url"]
+        expected_base_url = "/".join(
+            [
+                client._connection.API_BASE_URL,
+                "storage",
+                client._connection.API_VERSION,
+                "b",
+            ]
+        )
         self.assertTrue(requested_url.startswith(expected_base_url))
 
         expected_query = {
-            'project': [PROJECT],
-            'maxResults': [str(MAX_RESULTS)],
-            'pageToken': [PAGE_TOKEN],
-            'prefix': [PREFIX],
-            'projection': [PROJECTION],
-            'fields': [FIELDS],
+            "project": [PROJECT],
+            "maxResults": [str(MAX_RESULTS)],
+            "pageToken": [PAGE_TOKEN],
+            "prefix": [PREFIX],
+            "projection": [PROJECTION],
+            "fields": [FIELDS],
         }
         uri_parts = urlparse(requested_url)
         self.assertEqual(parse_qs(uri_parts.query), expected_query)
@@ -573,7 +592,7 @@ class TestClient(unittest.TestCase):
     def test_page_empty_response(self):
         from google.api_core import page_iterator
 
-        project = 'PROJECT'
+        project = "PROJECT"
         credentials = _make_credentials()
         client = self._make_one(project=project, credentials=credentials)
         iterator = client.list_buckets()
@@ -585,12 +604,12 @@ class TestClient(unittest.TestCase):
         import six
         from google.cloud.storage.bucket import Bucket
 
-        project = 'PROJECT'
+        project = "PROJECT"
         credentials = _make_credentials()
         client = self._make_one(project=project, credentials=credentials)
 
-        blob_name = 'bucket-name'
-        response = {'items': [{'name': blob_name}]}
+        blob_name = "bucket-name"
+        response = {"items": [{"name": blob_name}]}
 
         def dummy_response():
             return response
